<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Report insights webservice definitions.
 *
 * @package    local_faat
 * @copyright  Daniel Neis Araujo <danielneis@gmail.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$functions = array(

    'local_faat_create_quiz' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'create_quiz',
        'description' => 'Create a quiz',
        'type'        => 'write',
    ),
    'local_faat_update_quiz' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'update_quiz',
        'description' => 'Update a quiz',
        'type'        => 'write',
    ),
    'local_faat_delete_quiz' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'delete_quiz',
        'description' => 'Delete a quiz',
        'type'        => 'write',
    ),
    'local_faat_create_question' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'create_question',
        'description' => 'Create a question',
        'type'        => 'write',
    ),
    'local_faat_update_question' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'update_question',
        'description' => 'Update a question',
        'type'        => 'write',
    ),
    'local_faat_delete_question' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'delete_question',
        'description' => 'Delete a question',
        'type'        => 'write',
    ),
    'local_faat_grade_question' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'grade_question',
        'description' => 'Give a grade and a feedback for a question attempt',
        'type'        => 'write',
    ),
    'local_faat_get_quiz_attempts' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'get_quiz_attempts',
        'description' => 'Get all attempts of a quiz',
        'type'        => 'read',
    ),
    'local_faat_update_review' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'update_review',
        'description' => 'Update review options of a quiz',
        'type'        => 'write',
    ),
    'local_faat_quiz_override' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'quiz_override',
        'description' => 'Override quiz options for a user',
        'type'        => 'write',
    ),
    'local_faat_quiz_process_attempt' => array(
        'classname'   => 'local_faat\external',
        'methodname'  => 'quiz_process_attempt',
        'description' => 'Saves quiz attempt for a user',
        'type'        => 'write',
    ),
);

// Pre-built service.
$services = [
    'FAAT Webservices' => [
        'functions' => [
            'local_faat_create_quiz',
            'local_faat_update_quiz',
            'local_faat_delete_quiz',
            'local_faat_create_question',
            'local_faat_update_question',
            'local_faat_delete_question',
            'local_faat_grade_question',
            'local_faat_get_quiz_attempts',
            'local_faat_update_review',
            'local_faat_quiz_override',
            'local_faat_quiz_process_attempt',
        ],
        'restrictedusers' => 0,
        'enabled' => 1,
        'shortname' => 'faat_webservices',
    ]
];
